@@ -32,7 +32,7 @@ def get_cygwin_dir():
 
     raise ValueError("Cygwin directory unknown; please call lifelib.add_cygdir(r'D:\\path\\to\\cygwin64') or lifelib.install_cygwin()")
 
-def install_cygwin(root_directory=None, packages=['python2', 'python2-numpy', 'python3', 'python3-numpy', 'gcc-g++', 'make', 'git']):
+def install_cygwin(root_directory=None, packages=['python2', 'python2-numpy', 'python3', 'python3-numpy', 'gcc-core', 'gcc-g++', 'make', 'git']):
     '''
     For lifelib to run correctly on Windows, there needs to be a 64-bit Cygwin
     installation with g++, Python, and numpy. The user is free to download and
@@ -150,7 +150,10 @@ def run_tests():
 
     print("Warning: if you are in a Jupyter notebook you will not see output until the tests complete.")
     print("Use the terminal to view periodic progress...")
-    subprocess.check_call(get_local_bash() + ['tests/test_all.sh', this_python])
+    if (os.name == 'nt'):
+        subprocess.check_call(get_local_bash() + ['tests/test_all.sh'])
+    else:
+        subprocess.check_call(get_local_bash() + ['tests/test_all.sh', this_python])
     print("Completed tests successfully.")
 
 
@@ -399,13 +402,13 @@ def write_all_iterators(f, hist, rules, families):
     f.write('\n\n#endif\n\n')
 
 
-def reset_tree(rule='b3s23'):
+def reset_tree(rule='b3s23', throw_error=False):
 
     try:
         cwd = os.path.abspath(os.getcwd())
         generate_code([rule], clean_before=True)
     except:
-        if (rule != "b3s23"):
+        if throw_error:
             raise
         else:
             import warnings
