@@ -6,5 +6,7 @@
 export PATH="/usr/local/bin:/usr/bin:/bin:$PATH"
 
 cd "$( dirname "${BASH_SOURCE[0]}" )"
+export CHERE_INVOKING=1
+. /etc/profile
 
 "$@"
