@@ -194,6 +194,8 @@ class iwriter_base(object):
 
             if (newrows <= 16):
                 bindices = list(range(0, newrows // 2))
+            elif (newrows == 28):
+                bindices = [8, 9, 10, 11, 12, 13]
             else:
                 bindices = list(range(4, newrows // 2))
             lindices = list(range(newrows - 2, newrows))
