@@ -127,8 +127,7 @@ extern "C"
 
     void* Hashsoup(void* lt, const char *rule, const char *symmetry, const char *seed) {
         auto lab = reinterpret_cast<apg::lifetree_abstract<uint32_t>*>(lt);
-        std::vector<apg::bitworld> vbw;
-        vbw.push_back(apg::hashsoup(std::string(seed), std::string(symmetry)));
+        std::vector<apg::bitworld> vbw = apg::hashsoup(std::string(seed), std::string(symmetry));
         return new(std::nothrow) apg::pattern(lab, vbw, std::string(rule));
     }
 
