@@ -69,14 +69,22 @@ namespace apg {
         virtual void force_gc() = 0;
         virtual bool threshold_gc(uint64_t threshold) = 0;
         virtual uint64_t getcell_recurse(hypernode<I> hnode, uint64_t x, uint64_t y) = 0;
-        virtual void write_macrocell(std::ostream &outstream, hypernode<I> hnode, std::string rule) = 0;
+        virtual void write_macrocell(std::ostream &outstream, hypernode<I> hnode, std::string rule, int multistate) = 0;
         virtual void write_macrocell_header(std::ostream &outstream) = 0;
-        virtual void write_macrocell_headerless(std::ostream &outstream, hypernode<I> hnode, std::string rule) = 0;
+        virtual void write_macrocell_headerless(std::ostream &outstream, hypernode<I> hnode, std::string rule, int multistate) = 0;
         virtual void getcells_recurse(hypernode<I> hnode, uint64_t x, uint64_t y, std::map<std::pair<uint64_t, uint64_t>, uint64_t> &cells) = 0;
         virtual void write_rle(std::ostream &outstream, hypernode<I> hnode, std::string rule) = 0;
         virtual hypernode<I> _string32(std::string s) = 0;
         virtual std::string _string32(hypernode<I> hnode) = 0;
 
+        void write_macrocell(std::ostream &outstream, hypernode<I> hnode, std::string rule) {
+            write_macrocell(outstream, hnode, rule, 2);
+        }
+
+        void write_macrocell_headerless(std::ostream &outstream, hypernode<I> hnode, std::string rule) {
+            write_macrocell_headerless(outstream, hnode, rule, 2);
+        }
+
         bool threshold_gc() {
             return threshold_gc(gc_threshold);
         }
