@@ -619,7 +619,7 @@ class Pattern(object):
 
     def download_samples(self, **kwargs):
 
-        return self.owner.download_samples(self.getrule(), self.apgcode, **kwargs)
+        return self.owner.download_samples(self.apgcode, self.getrule(), **kwargs)
 
     @property
     def period(self):
