@@ -4,6 +4,8 @@ from .samples import download_samples as dsamples
 from .samples import validate_symmetry
 import os
 
+from ..genera import sanirule
+
 floats = {}
 
 
@@ -79,9 +81,7 @@ class Lifetree(object):
                 else:
                     raise TypeError("For headerless RLE, rule must be specified unless session has a unique rule")
 
-            rule = rule.lower()
-
-            self.session.verify_rule(rule)
+            rule = self.session.verify_rule(rule)
             pptr = self.lifelib('CreatePatternFromRLE', self.ptr, rle, rule)
 
             is_apgcode = ('_' in rle) and ('!' not in rle)
@@ -134,9 +134,14 @@ class Session(object):
 
     def verify_rule(self, rule):
 
-        if (len(rule) > 7) and (rule[-6:] == 'istory'):
-            rule = rule[:-7]
+        rule = sanirule(rule)
 
-        if rule not in self.rules:
+        if (len(rule) > 7) and (rule[-6:] == 'istory'):
+            newrule = rule[:-7]
+        else:
+            newrule = rule
+
+        if newrule not in self.rules:
             raise ValueError("Rule %s is not in the configured rules %s for this session" % (rule, self.rules))
 
+        return rule
