@@ -1,6 +1,7 @@
 #pragma once
 #include <string>
 #include <stdint.h>
+#include <sstream>
 
 namespace apg {
 
@@ -123,10 +124,44 @@ namespace apg {
         return outrule;
     }
 
+    std::string decapitalise(std::string inrule) {
+
+        std::string lowercase = "";
+        std::string rulename = "_";
+
+        for (uint64_t i = 0; i < inrule.length(); i++) {
+            char c = inrule[i];
+            if ((c >= 'a') && (c <= 'z') && (i == 0)) { c -= 32; }
+            if ((c >= 'A') && (c <= 'Z')) {
+                c += 32;
+                if (i == 0) {
+                    rulename = "x";
+                } else {
+                    std::ostringstream ss;
+                    ss << "x";
+                    ss << i;
+                    ss << rulename;
+                    rulename = ss.str();
+                }
+            }
+            lowercase.append(1, c);
+        }
+
+        if (lowercase == inrule) { return inrule; }
+
+        rulename = rulename + lowercase;
+
+        if (rulename[0] != 'x') {
+            rulename = "x" + rulename;
+        }
+
+        return rulename;
+
+    }
+
     std::string sanirule(std::string inrule) {
 
         std::string outrule = inrule;
-        int slashcount = 0;
 
         while (outrule.length() > 0) {
             char x = outrule[outrule.length() - 1];
@@ -146,8 +181,24 @@ namespace apg {
             }
         }
 
+        if ((outrule.length() > 7) && (outrule.substr(outrule.length() - 6) == "istory")) {
+            return sanirule(outrule.substr(0, outrule.length() - 7)) + "History";
+        }
+
+        if (outrule == "Life") { return "b3s23"; }
+        if (outrule == "PedestrianLife") { return "b38s23"; }
+        if (outrule == "DryLife") { return "b37s23"; }
+        if (outrule == "HighLife") { return "b36s23"; }
+
+        int slashcount = 0;
+        int commacount = 0;
         for (uint32_t i = 0; i < outrule.length(); i++) {
             slashcount += (outrule[i] == '/');
+            commacount += (outrule[i] == ',');
+        }
+
+        if (slashcount + commacount == 0) {
+            return decapitalise(outrule);
         }
 
         if ((slashcount >= 1) && (outrule[0] != 'B')) {
@@ -173,10 +224,6 @@ namespace apg {
             }
         }
 
-        replace(outrule, "PedestrianLife", "b38s23");
-        replace(outrule, "DryLife", "b37s23");
-        replace(outrule, "HighLife", "b36s23");
-        replace(outrule, "Life", "b3s23");
         return outrule;
     }
 }
