@@ -116,13 +116,26 @@ namespace apg {
             d |= (((uint64_t) digest[2*j+17]) << 8*j);
         }
 
+        if ((symmetry == "C1") || (symmetry == "D2_x")) {
+            #ifdef __AVX512F__
+            bw.world[std::pair<int32_t, int32_t>(1, 2)] = b;
+            bw.world[std::pair<int32_t, int32_t>(2, 2)] = a;
+            bw.world[std::pair<int32_t, int32_t>(1, 3)] = d;
+            bw.world[std::pair<int32_t, int32_t>(2, 3)] = c;
+            #else
+            bw.world[std::pair<int32_t, int32_t>(1, 1)] = b;
+            bw.world[std::pair<int32_t, int32_t>(2, 1)] = a;
+            bw.world[std::pair<int32_t, int32_t>(1, 2)] = d;
+            bw.world[std::pair<int32_t, int32_t>(2, 2)] = c;
+            #endif
+            return bw;
+        }
+
         bw.world[std::pair<int32_t, int32_t>(0, 0)] = b;
         bw.world[std::pair<int32_t, int32_t>(1, 0)] = a;
         bw.world[std::pair<int32_t, int32_t>(0, 1)] = d;
         bw.world[std::pair<int32_t, int32_t>(1, 1)] = c;
 
-        if ((symmetry == "C1") || (symmetry == "D2_x")) { return bw; }
-
         bitworld dbw;
         dbw.world[std::pair<int32_t, int32_t>(0, 0)] = uint64_vreflect(uint64_hreflect(c));
         dbw.world[std::pair<int32_t, int32_t>(1, 0)] = uint64_vreflect(uint64_hreflect(d));
@@ -180,12 +193,16 @@ namespace apg {
 
     }
 
-    bitworld hashsoup(std::string prehash, std::string full_symmetry) {
+    std::vector<bitworld> hashsoup(std::string prehash, std::string full_symmetry) {
 
         if (full_symmetry.find("stdin") != std::string::npos) {
-            std::string rle = prehash.substr(prehash.find('-'));
-            auto bvec = rle2vec(rle);
-            return bvec[0];
+            auto pos = prehash.find('-');
+            if (pos == std::string::npos) {
+                return hashsoup(prehash, "C1");
+            } else {
+                std::string rle = prehash.substr(pos);
+                return rle2vec(rle);
+            }
         }
 
         std::string symmetry = full_symmetry;
@@ -224,7 +241,9 @@ namespace apg {
             bw = bw.inflate();
         }
 
-        return bw;
+        std::vector<bitworld> bvec;
+        bvec.push_back(bw);
+        return bvec;
     }
 
 }
