@@ -14,6 +14,13 @@ class TestGoL(unittest.TestCase):
         self.sess = lifelib.load_rules('b3s23')
         self.lt = self.sess.lifetree(memory=1000, n_layers=4)
 
+    def test_samples(self):
+
+        pat = self.lt.pattern('xp40_33zxs48g69gvzx3021zy833')
+        samples = pat.download_samples()
+        periods = [s[10000][-1000:1000, -1000:1000].period for s in samples['C2_2']]
+        self.assertEqual(periods[:20], [40]*20)
+
     def test_hashsoup(self):
 
         x = self.lt.hashsoup("b3s23", "C1", "n_GcpqZ62YqD3310086454")
